package com.qianwankj.vt.vonage.flutter_vonage

import androidx.annotation.NonNull
import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.plugin.common.EventChannel
import io.flutter.plugin.common.EventChannel.EventSink
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result

class FlutterVonagePlugin : FlutterPlugin, MethodCallHandler {

    private lateinit var mVonageHelper: VonageHelper
    private lateinit var methodChannel: MethodChannel
    private lateinit var eventChannel: EventChannel

    override fun onAttachedToEngine(@NonNull flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
        mVonageHelper = VonageHelper(flutterPluginBinding.applicationContext)

        val messenger = flutterPluginBinding.binaryMessenger
        methodChannel = MethodChannel(messenger, Constants.METHOD_CHANNEL_NAME)
        eventChannel = EventChannel(messenger, Constants.EVENT_CHANNEL_NAME)

        methodChannel.setMethodCallHandler(this)
        eventChannel.setStreamHandler(object : EventChannel.StreamHandler {
            override fun onListen(arguments: Any?, events: EventSink) {
                mVonageHelper.eventSink = events
            }

            override fun onCancel(arguments: Any?) {
                mVonageHelper.eventSink = null
            }
        })
    }

    override fun onDetachedFromEngine(@NonNull binding: FlutterPlugin.FlutterPluginBinding) {
        mVonageHelper.destroy()
    }

    override fun onMethodCall(@NonNull call: MethodCall, @NonNull result: Result) {
        mVonageHelper.onMethodCall(call, result)
    }
}
